PTYng -- Pseudo-terminal utilities
========

Fork of ``pty`` aiming to enhance performance of the full ``stdlib`` Python API.

Download
--------

Standalone releases are available on PyPI:
http://pypi.python.org/pypi/ptyng/

Development
-----------

The main development takes place in the Python standard library: see
the `Python developer's guide <http://docs.python.org/devguide/>`_.
In particular, new features should be submitted to the
`Python bug tracker <http://bugs.python.org/>`_.

Documentation
-------------

Refer to the
`standard pty <http://docs.python.org/dev/library/pty.html>`_
documentation.
